HarmonyOsVersionPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • HarmonyOsVersionPlatform
Implementers

Constructors

HarmonyOsVersionPlatform()
Constructs a HarmonyOsVersionPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
osVersion() → Future<String?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ HarmonyOsVersionPlatform
The default instance of HarmonyOsVersionPlatform to use.
getter/setter pair